@@ -54,7 +54,8 @@ def _list_table(headers, data, title='', columns=None):
 
 def _indent(text, n=2):
     padding = ' ' * n
-    return '\n'.join(padding + l if l else l for l in text.splitlines())
+    # we don't want to indent blank lines so just output them as-is
+    return '\n'.join(padding + x if x else '' for x in text.splitlines())
 
 
 def _make_anchor_target(group_name, option_name):
@@ -201,7 +202,8 @@ def _format_group(namespace, group_name, group_obj):
     yield ''
 
     if group_obj and group_obj.help:
-        yield _indent(group_obj.help.rstrip())
+        for line in group_obj.help.strip().splitlines():
+            yield _indent(line.rstrip())
         yield ''
 
 
@@ -301,9 +303,12 @@ class ShowOptionsDirective(rst.Directive):
             ]
 
         result = ViewList()
-        source_name = '<' + __name__ + '>'
-        for line in _format_option_help(namespaces, split_namespaces):
-            result.append(line, source_name)
+        source_name = self.state.document.current_source
+
+        for count, line in enumerate(_format_option_help(
+                namespaces, split_namespaces)):
+            result.append(line, source_name, count)
+            LOG.debug(' '.join(['%5d' % (count), line]))
 
         node = nodes.section()
         node.document = self.state.document
